// device-management.component.ts
import { Component, OnInit } from '@angular/core';
import { CloudObject } from './cloud-object';
import { CloudQuery } from './../lib/ncloud.ts';

@Component({
  selector: 'app-device-management',
  standalone: true,
  imports: [
    // 确保导入了必要的模块
  ],
  templateUrl: './device-management.component.html',
  styleUrls: ['./device-management.component.scss']
})
export class DeviceManagementComponent implements OnInit {
  devices: CloudObject[] = [];
  newDeviceName: string = '';
  selectedDevice: CloudObject | undefined;

  private deviceQuery: CloudQuery;

  constructor() {
    this.deviceQuery = new CloudQuery("Device");
  }

  async ngOnInit() {
    await this.loadDevices();
  }

  async loadDevices() {
    const devices = await this.deviceQuery.find();
    this.devices = devices;
  }

  async addDevice() {
    const device = new CloudObject("Device");
    device.set({ name: this.newDeviceName });
    await device.save();
    this.devices.push(device);
    this.newDeviceName = '';
  }

  async deleteDevice(device: CloudObject) {
    await device.destroy();
    this.devices = this.devices.filter(d => d.id !== device.id);
  }

  selectDevice(device: CloudObject) {
    this.selectedDevice = device;
  }
}